import configparser
from typing import Tuple

def read_config(file_path: str) -> Tuple[int, int, int]:
    """
    读取配置文件并返回最小伤害、最大伤害和伤害减免百分比。
    
    Args:
        file_path (str): 配置文件的路径。
    
    Returns:
        Tuple[int, int, int]: 包含最小伤害、最大伤害和伤害减免百分比的元组。
    """
    config = configparser.ConfigParser()
    config.read(file_path)

    min_damage = int(config.get('damage_reduction', 'min_damage'))
    max_damage = int(config.get('damage_reduction', 'max_damage'))
    reduction_percentage = int(config.get('damage_reduction', 'reduction_percentage'))

    return min_damage, max_damage, reduction_percentage

def calculate_damage_reduction(min_damage: int, max_damage: int, reduction_percentage: int) -> Tuple[float, float]:
    """
    计算修复后的最小和最大伤害值。
    
    Args:
        min_damage (int): 原始最小伤害值。
        max_damage (int): 原始最大伤害值。
        reduction_percentage (int): 伤害减免百分比。
    
    Returns:
        Tuple[float, float]: 包含修复后的最小伤害和最大伤害的元组。
    """
    fixed_min_damage = min_damage * (1 - reduction_percentage / 100)
    fixed_max_damage = max_damage * (1 - reduction_percentage / 100)

    return fixed_min_damage, fixed_max_damage

def main():
    # 读取配置文件
    config_path = '/storage/emulated/0/Android/data/com.tencent.tmgp.pubgmhd/files/UE4Game/ShadowTrackerExtra/ShadowTrackerExtra/Saved/Config/Active.ini'
    min_damage, max_damage, reduction_percentage = read_config(config_path)

    # 计算修复后的伤害值
    fixed_min_damage, fixed_max_damage = calculate_damage_reduction(min_damage, max_damage, reduction_percentage)

    # 输出结果
    print(f"Original minimum damage value: {min_damage}")
    print(f"Original maximum damage value: {max_damage}")
    print(f"Minimum damage value after repair: {fixed_min_damage:.2f}")
    print(f"Maximum damage value after repair: {fixed_max_damage:.2f}")

if __name__ == "__main__":
    main()